Reference
=========

.. module:: leap

Runge-Kutta Methods
-------------------

.. automodule:: leap.rk
.. automodule:: leap.rk.imex

Multi-Step Methods
------------------
.. automodule:: leap.multistep

Multi-Rate Multi-Step Methods
-----------------------------

.. automodule:: leap.multistep.multirate

Analysis
--------

.. automodule:: leap.step_matrix
.. automodule:: leap.stability

Transformation
--------------

.. automodule:: leap.transform
